#[repr(transparent)]pub struct Hplr(pub u32);Expand description
SNVS_HP Lock Register
Tuple Fields
0: u32Implementations
Sourceimpl Hplr
impl Hplr
Sourcepub const fn zmk_wsl(&self) -> ZmkWsl
pub const fn zmk_wsl(&self) -> ZmkWsl
Zeroizable Master Key Write Soft Lock When set, prevents any writes (software and hardware) to the ZMK registers and the ZMK_HWP, ZMK_VAL, and ZMK_ECC_EN fields of the LPMKCR
Sourcepub const fn set_zmk_wsl(&mut self, val: ZmkWsl)
pub const fn set_zmk_wsl(&mut self, val: ZmkWsl)
Zeroizable Master Key Write Soft Lock When set, prevents any writes (software and hardware) to the ZMK registers and the ZMK_HWP, ZMK_VAL, and ZMK_ECC_EN fields of the LPMKCR
Sourcepub const fn zmk_rsl(&self) -> ZmkRsl
pub const fn zmk_rsl(&self) -> ZmkRsl
Zeroizable Master Key Read Soft Lock When set, prevents any software reads to the ZMK Registers and ZMK_ECC_VALUE field of the LPMKCR
Sourcepub const fn set_zmk_rsl(&mut self, val: ZmkRsl)
pub const fn set_zmk_rsl(&mut self, val: ZmkRsl)
Zeroizable Master Key Read Soft Lock When set, prevents any software reads to the ZMK Registers and ZMK_ECC_VALUE field of the LPMKCR
Sourcepub const fn srtc_sl(&self) -> SrtcSl
pub const fn srtc_sl(&self) -> SrtcSl
Secure Real Time Counter Soft Lock When set, prevents any writes to the SRTC Registers, SRTC_ENV, and SRTC_INV_EN bits
Sourcepub const fn set_srtc_sl(&mut self, val: SrtcSl)
pub const fn set_srtc_sl(&mut self, val: SrtcSl)
Secure Real Time Counter Soft Lock When set, prevents any writes to the SRTC Registers, SRTC_ENV, and SRTC_INV_EN bits
Sourcepub const fn lpcalb_sl(&self) -> LpcalbSl
pub const fn lpcalb_sl(&self) -> LpcalbSl
LP Calibration Soft Lock When set, prevents any writes to the LP Calibration Value (LPCALB_VAL) and LP Calibration Enable (LPCALB_EN)
Sourcepub const fn set_lpcalb_sl(&mut self, val: LpcalbSl)
pub const fn set_lpcalb_sl(&mut self, val: LpcalbSl)
LP Calibration Soft Lock When set, prevents any writes to the LP Calibration Value (LPCALB_VAL) and LP Calibration Enable (LPCALB_EN)
Sourcepub const fn mc_sl(&self) -> McSl
pub const fn mc_sl(&self) -> McSl
Monotonic Counter Soft Lock When set, prevents any writes (increments) to the MC Registers and MC_ENV bit
Sourcepub const fn set_mc_sl(&mut self, val: McSl)
pub const fn set_mc_sl(&mut self, val: McSl)
Monotonic Counter Soft Lock When set, prevents any writes (increments) to the MC Registers and MC_ENV bit
Sourcepub const fn gpr_sl(&self) -> GprSl
pub const fn gpr_sl(&self) -> GprSl
General Purpose Register Soft Lock When set, prevents any writes to the GPR
Sourcepub const fn set_gpr_sl(&mut self, val: GprSl)
pub const fn set_gpr_sl(&mut self, val: GprSl)
General Purpose Register Soft Lock When set, prevents any writes to the GPR
Sourcepub const fn lpsvcr_sl(&self) -> LpsvcrSl
pub const fn lpsvcr_sl(&self) -> LpsvcrSl
LP Security Violation Control Register Soft Lock When set, prevents any writes to the LPSVCR
Sourcepub const fn set_lpsvcr_sl(&mut self, val: LpsvcrSl)
pub const fn set_lpsvcr_sl(&mut self, val: LpsvcrSl)
LP Security Violation Control Register Soft Lock When set, prevents any writes to the LPSVCR
Sourcepub const fn lptgfcr_sl(&self) -> LptgfcrSl
pub const fn lptgfcr_sl(&self) -> LptgfcrSl
LP Tamper Glitch Filter Configuration Register Soft Lock When set, prevents any writes to the LPTGFCR
Sourcepub const fn set_lptgfcr_sl(&mut self, val: LptgfcrSl)
pub const fn set_lptgfcr_sl(&mut self, val: LptgfcrSl)
LP Tamper Glitch Filter Configuration Register Soft Lock When set, prevents any writes to the LPTGFCR
Sourcepub const fn lpsecr_sl(&self) -> LpsecrSl
pub const fn lpsecr_sl(&self) -> LpsecrSl
LP Security Events Configuration Register Soft Lock When set, prevents any writes to the LPSECR
Sourcepub const fn set_lpsecr_sl(&mut self, val: LpsecrSl)
pub const fn set_lpsecr_sl(&mut self, val: LpsecrSl)
LP Security Events Configuration Register Soft Lock When set, prevents any writes to the LPSECR
Sourcepub const fn mks_sl(&self) -> MksSl
pub const fn mks_sl(&self) -> MksSl
Master Key Select Soft Lock When set, prevents any writes to the MASTER_KEY_SEL field of the LPMKCR
Sourcepub const fn set_mks_sl(&mut self, val: MksSl)
pub const fn set_mks_sl(&mut self, val: MksSl)
Master Key Select Soft Lock When set, prevents any writes to the MASTER_KEY_SEL field of the LPMKCR
Sourcepub const fn hpsvcr_l(&self) -> HpsvcrL
pub const fn hpsvcr_l(&self) -> HpsvcrL
HP Security Violation Control Register Lock When set, prevents any writes to the HPSVCR
Sourcepub const fn set_hpsvcr_l(&mut self, val: HpsvcrL)
pub const fn set_hpsvcr_l(&mut self, val: HpsvcrL)
HP Security Violation Control Register Lock When set, prevents any writes to the HPSVCR
Sourcepub const fn hpsicr_l(&self) -> HpsicrL
pub const fn hpsicr_l(&self) -> HpsicrL
HP Security Interrupt Control Register Lock When set, prevents any writes to the HPSICR
Sourcepub const fn set_hpsicr_l(&mut self, val: HpsicrL)
pub const fn set_hpsicr_l(&mut self, val: HpsicrL)
HP Security Interrupt Control Register Lock When set, prevents any writes to the HPSICR