nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Hpsr

Struct Hpsr 

#[repr(transparent)]
pub struct Hpsr(pub u32);
SNVS_HP Status Register

Tuple Fields

0: u32

Implementations

Source

impl Hpsr

pub const fn hpta(&self) -> Hpta

HP Time Alarm Indicates that the HP Time Alarm has occurred since this bit was last cleared.

pub const fn set_hpta(&mut self, val: Hpta)

HP Time Alarm Indicates that the HP Time Alarm has occurred since this bit was last cleared.

pub const fn pi(&self) -> Pi

Periodic Interrupt Indicates that periodic interrupt has occurred since this bit was last cleared.

pub const fn set_pi(&mut self, val: Pi)

Periodic Interrupt Indicates that periodic interrupt has occurred since this bit was last cleared.

pub const fn lpdis(&self) -> bool

Low Power Disable If 1, the low power section has been disabled by means of an input signal to SNVS

pub const fn set_lpdis(&mut self, val: bool)

Low Power Disable If 1, the low power section has been disabled by means of an input signal to SNVS

pub const fn btn(&self) -> bool

Button Value of the BTN input

pub const fn set_btn(&mut self, val: bool)

Button Value of the BTN input

pub const fn bi(&self) -> bool

Button Interrupt Signal ipi_snvs_btn_int_b was asserted.

pub const fn set_bi(&mut self, val: bool)

Button Interrupt Signal ipi_snvs_btn_int_b was asserted.

pub const fn ssm_state(&self) -> SsmState

System Security Monitor State This field contains the encoded state of the SSM’s state machine

pub const fn set_ssm_state(&mut self, val: SsmState)

System Security Monitor State This field contains the encoded state of the SSM’s state machine

pub const fn sys_security_cfg(&self) -> SysSecurityCfg

System Security Configuration This field reflects the three security configuration inputs to SNVS

pub const fn set_sys_security_cfg(&mut self, val: SysSecurityCfg)

System Security Configuration This field reflects the three security configuration inputs to SNVS

pub const fn sys_secure_boot(&self) -> bool

System Secure Boot If SYS_SECURE_BOOT is 1, the chip boots from internal ROM

pub const fn set_sys_secure_boot(&mut self, val: bool)

System Secure Boot If SYS_SECURE_BOOT is 1, the chip boots from internal ROM

pub const fn otpmk_syndrome(&self) -> u16

One Time Programmable Master Key Syndrome In the case of a single-bit error, the eight lower bits of this value indicate the bit number of error location

pub const fn set_otpmk_syndrome(&mut self, val: u16)

One Time Programmable Master Key Syndrome In the case of a single-bit error, the eight lower bits of this value indicate the bit number of error location

pub const fn otpmk_zero(&self) -> OtpmkZero

One Time Programmable Master Key is Equal to Zero

pub const fn set_otpmk_zero(&mut self, val: OtpmkZero)

One Time Programmable Master Key is Equal to Zero

pub const fn zmk_zero(&self) -> ZmkZero

Zeroizable Master Key is Equal to Zero

pub const fn set_zmk_zero(&mut self, val: ZmkZero)

Zeroizable Master Key is Equal to Zero