nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Hpsvsr

Struct Hpsvsr 

#[repr(transparent)]
pub struct Hpsvsr(pub u32);
SNVS_HP Security Violation Status Register

Tuple Fields

0: u32

Implementations

Source

impl Hpsvsr

pub const fn sv0(&self) -> Sv0

Security Violation 0 security violation was detected.

pub const fn set_sv0(&mut self, val: Sv0)

Security Violation 0 security violation was detected.

pub const fn sv1(&self) -> Sv1

Security Violation 1 security violation was detected.

pub const fn set_sv1(&mut self, val: Sv1)

Security Violation 1 security violation was detected.

pub const fn sv2(&self) -> Sv2

Security Violation 2 security violation was detected.

pub const fn set_sv2(&mut self, val: Sv2)

Security Violation 2 security violation was detected.

pub const fn sv3(&self) -> Sv3

Security Violation 3 security violation was detected.

pub const fn set_sv3(&mut self, val: Sv3)

Security Violation 3 security violation was detected.

pub const fn sv4(&self) -> Sv4

Security Violation 4 security violation was detected.

pub const fn set_sv4(&mut self, val: Sv4)

Security Violation 4 security violation was detected.

pub const fn sv5(&self) -> Sv5

Security Violation 5 security violation was detected.

pub const fn set_sv5(&mut self, val: Sv5)

Security Violation 5 security violation was detected.

pub const fn sw_sv(&self) -> bool

Software Security Violation This bit is a read-only copy of the SW_SV bit in the HP Command Register

pub const fn set_sw_sv(&mut self, val: bool)

Software Security Violation This bit is a read-only copy of the SW_SV bit in the HP Command Register

pub const fn sw_fsv(&self) -> bool

Software Fatal Security Violation This bit is a read-only copy of the SW_FSV bit in the HP Command Register

pub const fn set_sw_fsv(&mut self, val: bool)

Software Fatal Security Violation This bit is a read-only copy of the SW_FSV bit in the HP Command Register

pub const fn sw_lpsv(&self) -> bool

LP Software Security Violation This bit is a read-only copy of the SW_LPSV bit in the HP Command Register

pub const fn set_sw_lpsv(&mut self, val: bool)

LP Software Security Violation This bit is a read-only copy of the SW_LPSV bit in the HP Command Register

pub const fn zmk_syndrome(&self) -> u16

Zeroizable Master Key Syndrome The ZMK syndrome indicates the single-bit error location and parity for the ZMK register

pub const fn set_zmk_syndrome(&mut self, val: u16)

Zeroizable Master Key Syndrome The ZMK syndrome indicates the single-bit error location and parity for the ZMK register

pub const fn zmk_ecc_fail(&self) -> ZmkEccFail

Zeroizable Master Key Error Correcting Code Check Failure When set, this bit triggers a bad key violation to the SSM and a security violation to the SNVS_LP section, which clears security sensitive data

pub const fn set_zmk_ecc_fail(&mut self, val: ZmkEccFail)

Zeroizable Master Key Error Correcting Code Check Failure When set, this bit triggers a bad key violation to the SSM and a security violation to the SNVS_LP section, which clears security sensitive data

pub const fn lp_sec_vio(&self) -> bool

LP Security Violation A security volation was detected in the SNVS low power section

pub const fn set_lp_sec_vio(&mut self, val: bool)

LP Security Violation A security volation was detected in the SNVS low power section