#[repr(transparent)]pub struct Lpmkcr(pub u32);Expand description
SNVS_LP Master Key Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Lpmkcr
impl Lpmkcr
Sourcepub const fn master_key_sel(&self) -> MasterKeySel
pub const fn master_key_sel(&self) -> MasterKeySel
Master Key Select These bits select the SNVS Master Key output when Master Key Select bits are enabled by MKS_EN bit in the HPCOMR
Sourcepub const fn set_master_key_sel(&mut self, val: MasterKeySel)
pub const fn set_master_key_sel(&mut self, val: MasterKeySel)
Master Key Select These bits select the SNVS Master Key output when Master Key Select bits are enabled by MKS_EN bit in the HPCOMR
Sourcepub const fn zmk_hwp(&self) -> ZmkHwp
pub const fn zmk_hwp(&self) -> ZmkHwp
Zeroizable Master Key hardware Programming mode When set, only the hardware key programming mechanism can set the ZMK and software cannot read it
Sourcepub const fn set_zmk_hwp(&mut self, val: ZmkHwp)
pub const fn set_zmk_hwp(&mut self, val: ZmkHwp)
Zeroizable Master Key hardware Programming mode When set, only the hardware key programming mechanism can set the ZMK and software cannot read it
Sourcepub const fn zmk_val(&self) -> bool
pub const fn zmk_val(&self) -> bool
Zeroizable Master Key Valid When set, the ZMK value can be selected by the master key control block for use by cryptographic modules
Sourcepub const fn set_zmk_val(&mut self, val: bool)
pub const fn set_zmk_val(&mut self, val: bool)
Zeroizable Master Key Valid When set, the ZMK value can be selected by the master key control block for use by cryptographic modules
Sourcepub const fn zmk_ecc_en(&self) -> bool
pub const fn zmk_ecc_en(&self) -> bool
Zeroizable Master Key Error Correcting Code Check Enable Writing one to this field automatically calculates and sets the ZMK ECC value in the ZMK_ECC_VALUE field of this register
Sourcepub const fn set_zmk_ecc_en(&mut self, val: bool)
pub const fn set_zmk_ecc_en(&mut self, val: bool)
Zeroizable Master Key Error Correcting Code Check Enable Writing one to this field automatically calculates and sets the ZMK ECC value in the ZMK_ECC_VALUE field of this register
Sourcepub const fn zmk_ecc_value(&self) -> u16
pub const fn zmk_ecc_value(&self) -> u16
Zeroizable Master Key Error Correcting Code Value This field is automatically calculated and set when one is written into ZMK_ECC_EN bit of this register
Sourcepub const fn set_zmk_ecc_value(&mut self, val: u16)
pub const fn set_zmk_ecc_value(&mut self, val: u16)
Zeroizable Master Key Error Correcting Code Value This field is automatically calculated and set when one is written into ZMK_ECC_EN bit of this register