nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Lpsmclr

Struct Lpsmclr 

#[repr(transparent)]
pub struct Lpsmclr(pub u32);
SNVS_LP Secure Monotonic Counter LSB Register

Tuple Fields

0: u32

Implementations

Source

impl Lpsmclr

pub const fn mon_counter(&self) -> u32

Monotonic Counter bits Note that writing to this register does not change the value of this field to the value that was written

pub const fn set_mon_counter(&mut self, val: u32)

Monotonic Counter bits Note that writing to this register does not change the value of this field to the value that was written