nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Lpsr

Struct Lpsr 

#[repr(transparent)]
pub struct Lpsr(pub u32);
SNVS_LP Status Register

Tuple Fields

0: u32

Implementations

Source

impl Lpsr

pub const fn lpta(&self) -> Lpta

LP Time Alarm

pub const fn set_lpta(&mut self, val: Lpta)

LP Time Alarm

pub const fn srtcr(&self) -> Srtcr

Secure Real Time Counter Rollover

pub const fn set_srtcr(&mut self, val: Srtcr)

Secure Real Time Counter Rollover

pub const fn mcr(&self) -> Mcr

Monotonic Counter Rollover

pub const fn set_mcr(&mut self, val: Mcr)

Monotonic Counter Rollover

pub const fn lvd(&self) -> Lvd

Digital Low Voltage Event Detected

pub const fn set_lvd(&mut self, val: Lvd)

Digital Low Voltage Event Detected

pub const fn ctd(&self) -> Ctd

Clock Tampering Detected

pub const fn set_ctd(&mut self, val: Ctd)

Clock Tampering Detected

pub const fn ttd(&self) -> Ttd

Temperature Tamper Detected

pub const fn set_ttd(&mut self, val: Ttd)

Temperature Tamper Detected

pub const fn vtd(&self) -> Vtd

Voltage Tampering Detected

pub const fn set_vtd(&mut self, val: Vtd)

Voltage Tampering Detected

pub const fn wmt1d(&self) -> Wmt1d

Wire-Mesh Tampering 1 Detected

pub const fn set_wmt1d(&mut self, val: Wmt1d)

Wire-Mesh Tampering 1 Detected

pub const fn wmt2d(&self) -> Wmt2d

Wire-Mesh Tampering 2 Detected

pub const fn set_wmt2d(&mut self, val: Wmt2d)

Wire-Mesh Tampering 2 Detected

pub const fn et1d(&self) -> Et1d

External Tampering 1 Detected

pub const fn set_et1d(&mut self, val: Et1d)

External Tampering 1 Detected

pub const fn et2d(&self) -> Et2d

External Tampering 2 Detected

pub const fn set_et2d(&mut self, val: Et2d)

External Tampering 2 Detected

pub const fn esvd(&self) -> Esvd

External Security Violation Detected Indicates that a security violation is detected on one of the HP security violation ports

pub const fn set_esvd(&mut self, val: Esvd)

External Security Violation Detected Indicates that a security violation is detected on one of the HP security violation ports

pub const fn eo(&self) -> Eo

Emergency Off This bit is set when a power off is requested.

pub const fn set_eo(&mut self, val: Eo)

Emergency Off This bit is set when a power off is requested.

pub const fn spof(&self) -> Spof

Set Power Off The SPO bit is set when the power button is pressed longer than the configured debounce time

pub const fn set_spof(&mut self, val: Spof)

Set Power Off The SPO bit is set when the power button is pressed longer than the configured debounce time

pub const fn spon(&self) -> Spon

Set Power On The SPON bit is set when the set_pwr_on_irq interrupt is triggered, which happens when the power button is pressed longer than the configured debounce time

pub const fn set_spon(&mut self, val: Spon)

Set Power On The SPON bit is set when the set_pwr_on_irq interrupt is triggered, which happens when the power button is pressed longer than the configured debounce time

pub const fn lpns(&self) -> Lpns

LP Section is Non-Secured Indicates that LP section was provisioned/programmed in the non-secure state

pub const fn set_lpns(&mut self, val: Lpns)

LP Section is Non-Secured Indicates that LP section was provisioned/programmed in the non-secure state

pub const fn lps(&self) -> Lps

LP Section is Secured Indicates that the LP section is provisioned/programmed in the secure or trusted state

pub const fn set_lps(&mut self, val: Lps)

LP Section is Secured Indicates that the LP section is provisioned/programmed in the secure or trusted state