nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Lptgfcr

Struct Lptgfcr 

#[repr(transparent)]
pub struct Lptgfcr(pub u32);
SNVS_LP Tamper Glitch Filters Configuration Register

Tuple Fields

0: u32

Implementations

Source

impl Lptgfcr

pub const fn wmtgf(&self) -> u8

Wire-Mesh Tamper Glitch Filter Configures the length of the digital glitch filter for the wire-mesh tamper 1 and 2 pins between 1 and 63 SRTC clock cycles

pub const fn set_wmtgf(&mut self, val: u8)

Wire-Mesh Tamper Glitch Filter Configures the length of the digital glitch filter for the wire-mesh tamper 1 and 2 pins between 1 and 63 SRTC clock cycles

pub const fn wmtgf_en(&self) -> WmtgfEn

Wire-Mesh Tamper Glitch Filter Enable When set, enables the wire-mesh tamper glitch filter

pub const fn set_wmtgf_en(&mut self, val: WmtgfEn)

Wire-Mesh Tamper Glitch Filter Enable When set, enables the wire-mesh tamper glitch filter

pub const fn etgf1(&self) -> u8

External Tamper Glitch Filter 1 Configures the length of the digital glitch filter for the external tamper 1 pin between 128 and 32640 SRTC clock cycles

pub const fn set_etgf1(&mut self, val: u8)

External Tamper Glitch Filter 1 Configures the length of the digital glitch filter for the external tamper 1 pin between 128 and 32640 SRTC clock cycles

pub const fn etgf1_en(&self) -> Etgf1En

External Tamper Glitch Filter 1 Enable When set, enables the external tamper glitch filter 1.

pub const fn set_etgf1_en(&mut self, val: Etgf1En)

External Tamper Glitch Filter 1 Enable When set, enables the external tamper glitch filter 1.

pub const fn etgf2(&self) -> u8

External Tamper Glitch Filter 2 Configures the length of the digital glitch filter for the external tamper 2 pin between 128 and 32640 SRTC clock cycles

pub const fn set_etgf2(&mut self, val: u8)

External Tamper Glitch Filter 2 Configures the length of the digital glitch filter for the external tamper 2 pin between 128 and 32640 SRTC clock cycles

pub const fn etgf2_en(&self) -> Etgf2En

External Tamper Glitch Filter 2 Enable When set, enables the external tamper glitch filter 2.

pub const fn set_etgf2_en(&mut self, val: Etgf2En)

External Tamper Glitch Filter 2 Enable When set, enables the external tamper glitch filter 2.