#[repr(transparent)]pub struct Hpsr(pub u32);Expand description
SNVS_HP Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Hpsr
impl Hpsr
Sourcepub const fn hpta(&self) -> Hpta
pub const fn hpta(&self) -> Hpta
HP Time Alarm Indicates that the HP Time Alarm has occurred since this bit was last cleared.
Sourcepub const fn set_hpta(&mut self, val: Hpta)
pub const fn set_hpta(&mut self, val: Hpta)
HP Time Alarm Indicates that the HP Time Alarm has occurred since this bit was last cleared.
Sourcepub const fn pi(&self) -> Pi
pub const fn pi(&self) -> Pi
Periodic Interrupt Indicates that periodic interrupt has occurred since this bit was last cleared.
Sourcepub const fn set_pi(&mut self, val: Pi)
pub const fn set_pi(&mut self, val: Pi)
Periodic Interrupt Indicates that periodic interrupt has occurred since this bit was last cleared.
Sourcepub const fn lpdis(&self) -> bool
pub const fn lpdis(&self) -> bool
Low Power Disable If 1, the low power section has been disabled by means of an input signal to SNVS
Sourcepub const fn set_lpdis(&mut self, val: bool)
pub const fn set_lpdis(&mut self, val: bool)
Low Power Disable If 1, the low power section has been disabled by means of an input signal to SNVS
Sourcepub const fn set_bi(&mut self, val: bool)
pub const fn set_bi(&mut self, val: bool)
Button Interrupt Signal ipi_snvs_btn_int_b was asserted.
Sourcepub const fn ssm_state(&self) -> SsmState
pub const fn ssm_state(&self) -> SsmState
System Security Monitor State This field contains the encoded state of the SSM’s state machine
Sourcepub const fn set_ssm_state(&mut self, val: SsmState)
pub const fn set_ssm_state(&mut self, val: SsmState)
System Security Monitor State This field contains the encoded state of the SSM’s state machine
Sourcepub const fn sys_security_cfg(&self) -> SysSecurityCfg
pub const fn sys_security_cfg(&self) -> SysSecurityCfg
System Security Configuration This field reflects the three security configuration inputs to SNVS
Sourcepub const fn set_sys_security_cfg(&mut self, val: SysSecurityCfg)
pub const fn set_sys_security_cfg(&mut self, val: SysSecurityCfg)
System Security Configuration This field reflects the three security configuration inputs to SNVS
Sourcepub const fn sys_secure_boot(&self) -> bool
pub const fn sys_secure_boot(&self) -> bool
System Secure Boot If SYS_SECURE_BOOT is 1, the chip boots from internal ROM
Sourcepub const fn set_sys_secure_boot(&mut self, val: bool)
pub const fn set_sys_secure_boot(&mut self, val: bool)
System Secure Boot If SYS_SECURE_BOOT is 1, the chip boots from internal ROM
Sourcepub const fn otpmk_syndrome(&self) -> u16
pub const fn otpmk_syndrome(&self) -> u16
One Time Programmable Master Key Syndrome In the case of a single-bit error, the eight lower bits of this value indicate the bit number of error location
Sourcepub const fn set_otpmk_syndrome(&mut self, val: u16)
pub const fn set_otpmk_syndrome(&mut self, val: u16)
One Time Programmable Master Key Syndrome In the case of a single-bit error, the eight lower bits of this value indicate the bit number of error location
Sourcepub const fn otpmk_zero(&self) -> OtpmkZero
pub const fn otpmk_zero(&self) -> OtpmkZero
One Time Programmable Master Key is Equal to Zero
Sourcepub const fn set_otpmk_zero(&mut self, val: OtpmkZero)
pub const fn set_otpmk_zero(&mut self, val: OtpmkZero)
One Time Programmable Master Key is Equal to Zero
Sourcepub const fn set_zmk_zero(&mut self, val: ZmkZero)
pub const fn set_zmk_zero(&mut self, val: ZmkZero)
Zeroizable Master Key is Equal to Zero