#[repr(transparent)]pub struct Lpsmclr(pub u32);Expand description
SNVS_LP Secure Monotonic Counter LSB Register
Tuple Fields
0: u32Implementations
Sourceimpl Lpsmclr
impl Lpsmclr
Sourcepub const fn mon_counter(&self) -> u32
pub const fn mon_counter(&self) -> u32
Monotonic Counter bits Note that writing to this register does not change the value of this field to the value that was written
Sourcepub const fn set_mon_counter(&mut self, val: u32)
pub const fn set_mon_counter(&mut self, val: u32)
Monotonic Counter bits Note that writing to this register does not change the value of this field to the value that was written