#[repr(transparent)]pub struct Lptdcr(pub u32);Expand description
SNVS_LP Tamper Detect Configuration Register
Tuple Fields
0: u32Implementations
Sourceimpl Lptdcr
impl Lptdcr
Sourcepub const fn srtcr_en(&self) -> bool
pub const fn srtcr_en(&self) -> bool
SRTC Rollover Enable When set, an SRTC rollover event generates an LP security violation.
Sourcepub const fn set_srtcr_en(&mut self, val: bool)
pub const fn set_srtcr_en(&mut self, val: bool)
SRTC Rollover Enable When set, an SRTC rollover event generates an LP security violation.
Sourcepub const fn mcr_en(&self) -> bool
pub const fn mcr_en(&self) -> bool
MC Rollover Enable When set, an MC Rollover event generates an LP security violation.
Sourcepub const fn set_mcr_en(&mut self, val: bool)
pub const fn set_mcr_en(&mut self, val: bool)
MC Rollover Enable When set, an MC Rollover event generates an LP security violation.
Sourcepub const fn ct_en(&self) -> bool
pub const fn ct_en(&self) -> bool
Clock Tamper Enable When set, a clock monitor tamper generates an LP security violation.
Sourcepub const fn set_ct_en(&mut self, val: bool)
pub const fn set_ct_en(&mut self, val: bool)
Clock Tamper Enable When set, a clock monitor tamper generates an LP security violation.
Sourcepub const fn tt_en(&self) -> bool
pub const fn tt_en(&self) -> bool
Temperature Tamper Enable When set, a temperature monitor tamper generates an LP security violation
Sourcepub const fn set_tt_en(&mut self, val: bool)
pub const fn set_tt_en(&mut self, val: bool)
Temperature Tamper Enable When set, a temperature monitor tamper generates an LP security violation
Sourcepub const fn vt_en(&self) -> bool
pub const fn vt_en(&self) -> bool
Voltage Tamper Enable Voltage Tamper Enable should be enabled 500 us after setting SCSC_SOSC_CTR [VOLT_TEMP_TAMPER_EN]
Sourcepub const fn set_vt_en(&mut self, val: bool)
pub const fn set_vt_en(&mut self, val: bool)
Voltage Tamper Enable Voltage Tamper Enable should be enabled 500 us after setting SCSC_SOSC_CTR [VOLT_TEMP_TAMPER_EN]
Sourcepub const fn wmt1_en(&self) -> bool
pub const fn wmt1_en(&self) -> bool
Wire-Mesh Tampering 1 Enable When set, wire-mesh tampering 1 detection generates an LP security violation
Sourcepub const fn set_wmt1_en(&mut self, val: bool)
pub const fn set_wmt1_en(&mut self, val: bool)
Wire-Mesh Tampering 1 Enable When set, wire-mesh tampering 1 detection generates an LP security violation
Sourcepub const fn wmt2_en(&self) -> bool
pub const fn wmt2_en(&self) -> bool
Wire-Mesh Tampering 2 Enable When set, wire-mesh tampering 2 detection generates an LP security violation
Sourcepub const fn set_wmt2_en(&mut self, val: bool)
pub const fn set_wmt2_en(&mut self, val: bool)
Wire-Mesh Tampering 2 Enable When set, wire-mesh tampering 2 detection generates an LP security violation
Sourcepub const fn et1_en(&self) -> bool
pub const fn et1_en(&self) -> bool
External Tampering 1 Enable When set, external tampering 1 detection generates an LP security violation
Sourcepub const fn set_et1_en(&mut self, val: bool)
pub const fn set_et1_en(&mut self, val: bool)
External Tampering 1 Enable When set, external tampering 1 detection generates an LP security violation
Sourcepub const fn et2_en(&self) -> bool
pub const fn et2_en(&self) -> bool
External Tampering 2 Enable When set, external tampering 2 detection generates an LP security violation
Sourcepub const fn set_et2_en(&mut self, val: bool)
pub const fn set_et2_en(&mut self, val: bool)
External Tampering 2 Enable When set, external tampering 2 detection generates an LP security violation
Sourcepub const fn et1p(&self) -> Et1p
pub const fn et1p(&self) -> Et1p
External Tampering 1 Polarity This bit is used to determine the polarity of external tamper 1.
Sourcepub const fn set_et1p(&mut self, val: Et1p)
pub const fn set_et1p(&mut self, val: Et1p)
External Tampering 1 Polarity This bit is used to determine the polarity of external tamper 1.
Sourcepub const fn et2p(&self) -> Et2p
pub const fn et2p(&self) -> Et2p
External Tampering 2 Polarity This bit is used to determine the polarity of external tamper 2.
Sourcepub const fn set_et2p(&mut self, val: Et2p)
pub const fn set_et2p(&mut self, val: Et2p)
External Tampering 2 Polarity This bit is used to determine the polarity of external tamper 2.
Sourcepub const fn pfd_observ(&self) -> bool
pub const fn pfd_observ(&self) -> bool
System Power Fail Detector (PFD) Observability Flop The asynchronous reset input of this flop is connected directly to the inverted output of the PFD analog circuitry (external to the SNVS block)
Sourcepub const fn set_pfd_observ(&mut self, val: bool)
pub const fn set_pfd_observ(&mut self, val: bool)
System Power Fail Detector (PFD) Observability Flop The asynchronous reset input of this flop is connected directly to the inverted output of the PFD analog circuitry (external to the SNVS block)
Sourcepub const fn por_observ(&self) -> bool
pub const fn por_observ(&self) -> bool
Power On Reset (POR) Observability Flop The asynchronous reset input of this flop is connected directly to the output of the POR analog circuitry (external to the SNVS
Sourcepub const fn set_por_observ(&mut self, val: bool)
pub const fn set_por_observ(&mut self, val: bool)
Power On Reset (POR) Observability Flop The asynchronous reset input of this flop is connected directly to the output of the POR analog circuitry (external to the SNVS
Sourcepub const fn ltdc(&self) -> u8
pub const fn ltdc(&self) -> u8
Low Temp Detect Configuration These configuration bits are wired as an output of the module.
Sourcepub const fn set_ltdc(&mut self, val: u8)
pub const fn set_ltdc(&mut self, val: u8)
Low Temp Detect Configuration These configuration bits are wired as an output of the module.
Sourcepub const fn htdc(&self) -> u8
pub const fn htdc(&self) -> u8
High Temperature Detect Configuration These configuration bits are wired as an output of the module
Sourcepub const fn set_htdc(&mut self, val: u8)
pub const fn set_htdc(&mut self, val: u8)
High Temperature Detect Configuration These configuration bits are wired as an output of the module
Sourcepub const fn vrc(&self) -> u8
pub const fn vrc(&self) -> u8
Voltage Reference Configuration These configuration bits are wired as an output of the module.
Sourcepub const fn set_vrc(&mut self, val: u8)
pub const fn set_vrc(&mut self, val: u8)
Voltage Reference Configuration These configuration bits are wired as an output of the module.